@@ -1,16 +1,16 @@
 #' Get node attribute values
-#' @description From a graph object of class
-#' \code{dgr_graph}, get node attribute values for
-#' one or more nodes.
-#' @param graph a graph object of class
-#' \code{dgr_graph}.
-#' @param nodes an optional vector of node IDs for
-#' filtering list of nodes present in the graph or
-#' node data frame.
-#' @param node_attr the name of the attribute for which
-#' to get values.
-#' @return a named vector of node attribute values for
-#' the attribute given by \code{node_attr} by node ID.
+#'
+#' From a graph object of class `dgr_graph`, get node attribute values for one
+#' or more nodes.
+#'
+#' @inheritParams render_graph
+#' @param nodes An optional vector of node IDs for filtering list of nodes
+#'   present in the graph or node data frame.
+#' @param node_attr The name of the attribute for which to get values.
+#'
+#' @return A named vector of node attribute values for the attribute given by
+#'   `node_attr` by node ID.
+#'
 #' @examples
 #' # Create a random graph using the
 #' # `add_gnm_graph()` function
@@ -38,10 +38,9 @@
 #'   get_node_attrs(
 #'     node_attr = value,
 #'     nodes = c(1, 3))
-#' @importFrom dplyr filter pull
-#' @importFrom rlang enquo UQ get_expr
-#' @export get_node_attrs
-
+#'
+#' @import rlang
+#' @export
 get_node_attrs <- function(graph,
                            node_attr,
                            nodes = NULL) {
@@ -59,9 +58,6 @@ get_node_attrs <- function(graph,
 
   node_attr <- rlang::enquo(node_attr)
 
-  # Create binding for a specific variable
-  id <- NULL
-
   if (rlang::enquo(node_attr) %>%
       rlang::get_expr() %>%
       as.character() %in% c("id", "nodes")) {
@@ -78,9 +74,7 @@ get_node_attrs <- function(graph,
   if (is.null(nodes)) {
 
     # Extract the node attribute values
-    node_attr_vals <-
-      ndf %>%
-      dplyr::pull(rlang::UQ(node_attr))
+    node_attr_vals <- ndf %>% dplyr::pull(!!node_attr)
 
     # Extract the node names
     node_names <- ndf$id
@@ -100,9 +94,7 @@ get_node_attrs <- function(graph,
       dplyr::filter(id %in% nodes)
 
     # Extract the node attribute values
-    node_attr_vals <-
-      ndf %>%
-      dplyr::pull(rlang::UQ(node_attr))
+    node_attr_vals <- ndf %>% dplyr::pull(!!node_attr)
 
     # Extract the node names
     node_names <- ndf$id
