@@ -306,25 +306,25 @@ trav_both_edge <- function(graph,
 
       from_join <-
         ndf %>%
-        dplyr::select_("id", copy_attrs_from) %>%
+        dplyr::select("id",!! enquo(copy_attrs_from)) %>%
         dplyr::filter(id %in% starting_nodes) %>%
         dplyr::right_join(
           valid_edges %>%
             dplyr::select(-rel) %>%
             dplyr::rename(e_id = id),
           by = c("id" = "from")) %>%
-        dplyr::select_("e_id", copy_attrs_from)
+        dplyr::select("e_id",!! enquo(copy_attrs_from))
 
       to_join <-
         ndf %>%
-        dplyr::select_("id", copy_attrs_from) %>%
+        dplyr::select("id",!! enquo(copy_attrs_from)) %>%
         dplyr::filter(id %in% starting_nodes) %>%
         dplyr::right_join(
           valid_edges %>%
             dplyr::select(-rel) %>%
             dplyr::rename(e_id = id),
           by = c("id" = "to")) %>%
-        dplyr::select_("e_id", copy_attrs_from)
+        dplyr::select("e_id",!! enquo(copy_attrs_from))
 
       if (!is.null(copy_attrs_as)) {
 
@@ -346,10 +346,9 @@ trav_both_edge <- function(graph,
         dplyr::left_join(edf, by = c("e_id" = "id")) %>%
         dplyr::rename(id = e_id) %>%
         dplyr::group_by(id) %>%
-        dplyr::summarize_(.dots = stats::setNames(
-          list(stats::as.formula(
-            paste0("~", agg, "(", copy_attrs_from, ", na.rm = TRUE)"))),
-          copy_attrs_from)) %>%
+        dplyr::summarize(!! copy_attrs_from :=
+                           match.fun(!! agg)(!! as.name(copy_attrs_from),
+                                             na.rm = TRUE)) %>%
         dplyr::right_join(edf, by = "id") %>%
         dplyr::select(id, from, to, rel, dplyr::everything()) %>%
         as.data.frame(stringsAsFractions = FALSE)
@@ -359,7 +358,7 @@ trav_both_edge <- function(graph,
 
       from_join <-
         ndf %>%
-        dplyr::select_("id", copy_attrs_from) %>%
+        dplyr::select("id",!! enquo(copy_attrs_from)) %>%
         dplyr::filter(id %in% starting_nodes)
 
       if (!is.null(copy_attrs_as)) {
@@ -403,11 +402,11 @@ trav_both_edge <- function(graph,
       # Drop the ".x" column
       from_join <-
         from_join %>%
-        dplyr::select_("e_id", copy_attrs_from)
+        dplyr::select("e_id",!! enquo(copy_attrs_from))
 
       to_join <-
         ndf %>%
-        dplyr::select_("id", copy_attrs_from) %>%
+        dplyr::select("id",!! enquo(copy_attrs_from)) %>%
         dplyr::filter(id %in% starting_nodes)
 
       if (!is.null(copy_attrs_as)) {
@@ -449,7 +448,7 @@ trav_both_edge <- function(graph,
       # Drop the ".x" column
       to_join <-
         to_join %>%
-        dplyr::select_("e_id", copy_attrs_from)
+        dplyr::select("e_id",!! enquo(copy_attrs_from))
 
       edges <-
         dplyr::bind_rows(
@@ -482,9 +481,9 @@ trav_both_edge <- function(graph,
         dplyr::arrange(e_id) %>%
         dplyr::rename(id = e_id) %>%
         dplyr::group_by(id) %>%
-        dplyr::summarize_(.dots = stats::setNames(
-          list(stats::as.formula(
-            paste0("~", agg, "(", copy_attrs_from, ", na.rm = TRUE)"))), copy_attrs_from)) %>%
+        dplyr::summarize(!! copy_attrs_from :=
+                            match.fun(!! agg)(!! as.name(copy_attrs_from),
+                                              na.rm = TRUE)) %>%
         dplyr::ungroup() %>%
         dplyr::right_join(edf, by = "id")
 
