@@ -35,7 +35,7 @@ HTMLWidgets.widget({
 
       try {
 
-        el.innerHTML = Viz(x.diagram, format="svg", engine=x.config.engine, options=x.config.options);
+        el.innerHTML = Viz(x.diagram, {format: "svg", engine: x.config.engine, ...x.config.options});
 
         makeResponsive(el);
 
@@ -47,7 +47,7 @@ HTMLWidgets.widget({
             // Get node id
             var nodeid = e.currentTarget.id;
             // Get node text object and make an array
-            var node_texts = $("#" + nodeid + " text");
+            var node_texts = $("#" + id + " #" + nodeid + " text");
             //var node_path = $("#" + nodeid + " path")[0];
             var text_array = node_texts.map(function() {return $(this).text(); }).toArray();
             // Build return object *obj* with node-id, node text values and node fill
